@@ -1,10 +1,10 @@
 context("convert_units")
 
 test_that("convert_units works", {
-  skip_on_cran()
-
-  a <- convert_units(udunits = "degree_C meter-1")
-  b <- convert_units(ucum = "Cel.m-1")
+  vcr::use_cassette("convert_units", {
+    a <- convert_units(udunits = "degree_C meter-1")
+    b <- convert_units(ucum = "Cel.m-1")
+  }, preserve_exact_body_bytes = TRUE)
 
   expect_is(a, "character")
   expect_equal(a, "Cel.m-1")
@@ -29,5 +29,6 @@ test_that("convert_units fails well", {
   skip_on_cran()
 
   expect_error(convert_units(), "One of udunits or ucum must be non-NULL")
-  expect_error(convert_units(udunits = "sec", ucum = "sec"), "Supply only one of udunits or ucum")
+  expect_error(convert_units(udunits = "sec", ucum = "sec"),
+    "Supply only one of udunits or ucum")
 })
