@@ -1,11 +1,11 @@
 context("ed_search")
 
 test_that("ed_search returns the correct", {
-  skip_on_cran()
-
-  a <- ed_search(query = 'temperature')
-  b <- ed_search(query = 'size')
-
+  vcr::use_cassette("ed_search", {
+    a <- ed_search(query = 'temperature')
+    b <- ed_search(query = 'size')
+  })
+  
   # class
   expect_is(a, "ed_search")
   expect_is(a$info, "data.frame")
@@ -19,12 +19,12 @@ test_that("ed_search returns the correct", {
 })
 
 test_that("ed_search works with different ERDDAP servers", {
-  skip_on_cran()
-
-  #' ## Marine Domain Awareness (MDA) (Italy)
-  d <- ed_search("temperature", url = "https://bluehub.jrc.ec.europa.eu/erddap/")
-  ## Marine Institute (Ireland)
-  e <- ed_search("temperature", url = "http://erddap.marine.ie/erddap/")
+  vcr::use_cassette("ed_search_diff_servers", {
+    d <- ed_search("wave",
+      url = "https://erddap.marine.ie/erddap/")
+    e <- ed_search("temperature",
+      url = "http://www.ifremer.fr/erddap/")
+  })
 
   expect_is(d, "ed_search")
   expect_is(d$info, "data.frame")
@@ -38,8 +38,10 @@ test_that("ed_search works with different ERDDAP servers", {
 test_that("ed_search correctly catches invalid parameter types", {
   skip_on_cran()
 
-  expect_error(ed_search(query = "temperature", page = "things"), "page not of class numeric")
-  expect_error(ed_search(query = "temperature", page_size = "adf"), "page_size not of class numeric")
+  expect_error(ed_search(query = "temperature", page = "things"),
+    "page not of class numeric")
+  expect_error(ed_search(query = "temperature", page_size = "adf"),
+    "page_size not of class numeric")
 })
 
 test_that("ed_search fails well", {
